Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.freedesktop.org/gstreamer/gst-plugins-rs.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastian Dröge <sebastian@centricular.com>2022-10-23 18:42:58 +0300
committerSebastian Dröge <sebastian@centricular.com>2022-10-23 20:46:08 +0300
commitf045099fc135d54a74b7a918e8ffcce5352ad3a7 (patch)
tree3ec9ec3beb0bdafb8b16fbf106c89354c5a0c3ea /video/webp
parent211cd095d69726a3a2208feddd921d05b60c6540 (diff)
Fix GObject type names, GStreamer debug category names and element factory names
Fixes https://gitlab.freedesktop.org/gstreamer/gst-plugins-rs/-/issues/198
Diffstat (limited to 'video/webp')
-rw-r--r--video/webp/src/dec/imp.rs6
-rw-r--r--video/webp/src/dec/mod.rs4
-rw-r--r--video/webp/tests/webpdec.rs2
3 files changed, 6 insertions, 6 deletions
diff --git a/video/webp/src/dec/imp.rs b/video/webp/src/dec/imp.rs
index 645f71e7f..8e8533856 100644
--- a/video/webp/src/dec/imp.rs
+++ b/video/webp/src/dec/imp.rs
@@ -19,9 +19,9 @@ use std::marker::PhantomData;
static CAT: Lazy<gst::DebugCategory> = Lazy::new(|| {
gst::DebugCategory::new(
- "webpdec-rs",
+ "rswebpdec",
gst::DebugColorFlags::empty(),
- Some("WebP decoder"),
+ Some("Rust WebP decoder"),
)
});
@@ -267,7 +267,7 @@ impl WebPDec {
#[glib::object_subclass]
impl ObjectSubclass for WebPDec {
- const NAME: &'static str = "RsWebPDec";
+ const NAME: &'static str = "GstRsWebPDec";
type Type = super::WebPDec;
type ParentType = gst::Element;
diff --git a/video/webp/tests/webpdec.rs b/video/webp/tests/webpdec.rs
index 95451faf9..de560a085 100644
--- a/video/webp/tests/webpdec.rs
+++ b/video/webp/tests/webpdec.rs
@@ -23,7 +23,7 @@ fn init() {
fn test_decode() {
init();
let data = include_bytes!("animated.webp").as_ref();
- let mut h = gst_check::Harness::new("webpdec-rs");
+ let mut h = gst_check::Harness::new("rswebpdec");
h.set_src_caps_str("image/webp");
diff --git a/video/webp/src/dec/mod.rs b/video/webp/src/dec/mod.rs
index 9bbd18305..e0f4f3196 100644
--- a/video/webp/src/dec/mod.rs
+++ b/video/webp/src/dec/mod.rs
@@ -8,7 +8,7 @@
// Example command-line:
//
// gst-launch-1.0 filesrc location=animated.webp ! webpdec-rs ! videoconvert ! autovideosink
use gst::glib;
use gst::prelude::*;
@@ -22,7 +22,7 @@ glib::wrapper! {
pub fn register(plugin: &gst::Plugin) -> Result<(), glib::BoolError> {
gst::Element::register(
Some(plugin),
- "webpdec-rs",
+ "rswebpdec",
gst::Rank::Primary,
WebPDec::static_type(),
)
@@ -8,7 +8,7 @@
// Example command-line:
//
-// gst-launch-1.0 filesrc location=animated.webp ! webpdec-rs ! videoconvert ! autovideosink
+// gst-launch-1.0 filesrc location=animated.webp ! rswebpdec ! videoconvert ! autovideosink
use gst::glib;
use gst::prelude::*;